Brabbel
=======

Brabbel is a small python based expression language which can be used to
evaluate simple expressions.

Brabbel provides the following set of features:

* Values: Strings, Numbers, Variables , Lists
* simple arithmetic operations: + - / *
* simple equation : < > <= >= == !=
* simple bool operation: and or not
* function calls: date, bool
* other: check if values is _in_ a list

Brabbel is the german term for the first "language" of a baby and emphasises
the reduced coverage of this language.
